# AGPL 3 or any later version
# Modern Dark Authentication Plugin for BDServer
# Enhances login and register pages to match modern homepage style

PluginData = {
    "author":{
        "title":"Madiator2011",
        "url":"https://shark.madiator.com/@madiator2011",
        "avatar":"https://shark.madiator.com/proxy/avatar.webp?url=https%3A%2F%2Fshark.madiator.com%2Ffiles%2F8076a50d-49db-4632-9d21-2e93ed53c500&avatar=1"
    },
    "title":"Modern Authentication",
    "description":"Make your login and register pages match the modern homepage style.",
    "license":"AGPL-3.0-or-later"}

def onHTML(server, html):
    """
    Enhance HTML for login and register pages with modern dark styling
    """
    
    # Only modify login and register pages
    if not (server.path.startswith('/login') or server.path.startswith('/register')):
        return html
    
    # First, let's add the missing closing tags to fix the HTML structure
    if '</body>' not in html:
        html = html + '</center></body></html>'
    
    # Modern dark styles matching the homepage
    modern_dark_styles = '''
<style>
/* Override base styles to match modern homepage */
body {
    margin: 0 !important;
    padding: 0 !important;
    font-family: system-ui, -apple-system, sans-serif !important;
    background: #1a1a2e !important;
    color: #F9F9FB !important;
    min-height: 100vh !important;
    display: flex !important;
    flex-direction: column !important;
}

/* Navigation bar - matching homepage style */
body > a.button:first-of-type {
    position: fixed !important;
    top: 20px !important;
    left: 20px !important;
    background: rgba(34, 34, 59, 0.8) !important;
    backdrop-filter: blur(20px) !important;
    border: 1px solid rgba(91, 46, 255, 0.2) !important;
    border-radius: 8px !important;
    padding: 12px 24px !important;
    color: #e2e8f0 !important;
    text-decoration: none !important;
    font-weight: 500 !important;
    z-index: 1000 !important;
    transition: all 0.3s !important;
}

body > a.button:first-of-type:hover {
    background: rgba(34, 34, 59, 0.95) !important;
    border-color: rgba(234, 127, 63, 0.6) !important;
    color: #EA7F3F !important;
    transform: translateY(-2px) !important;
    box-shadow: 0 4px 12px rgba(234, 127, 63, 0.3) !important;
}

/* Hide original center content */
center {
    display: none !important;
}

/* Modern Authentication Container */
.auth-wrapper {
    flex: 1 !important;
    display: flex !important;
    align-items: center !important;
    justify-content: center !important;
    padding: 20px !important;
    background: linear-gradient(135deg, #22223B 0%, #1a1a2e 50%, #2E2A8A 100%) !important;
}

.auth-container {
    width: 100% !important;
    max-width: 480px !important;
}

.auth-card {
    background: rgba(34, 34, 59, 0.4) !important;
    backdrop-filter: blur(20px) !important;
    border: 1px solid rgba(91, 46, 255, 0.2) !important;
    border-radius: 12px !important;
    overflow: hidden !important;
    transition: all 0.3s !important;
    box-shadow: 0 20px 40px rgba(0, 0, 0, 0.3) !important;
}

.auth-card:hover {
    transform: translateY(-4px) !important;
    box-shadow: 0 20px 40px rgba(234, 127, 63, 0.15) !important;
    border-color: rgba(234, 127, 63, 0.6) !important;
}

.auth-header {
    background: linear-gradient(135deg, rgba(91, 46, 255, 0.1) 0%, rgba(234, 127, 63, 0.1) 100%) !important;
    padding: 32px !important;
    text-align: center !important;
    border-bottom: 1px solid rgba(91, 46, 255, 0.2) !important;
}

.auth-title {
    font-size: 28px !important;
    font-weight: 600 !important;
    color: #e2e8f0 !important;
    margin: 0 0 8px 0 !important;
    letter-spacing: -0.025em !important;
}

.auth-subtitle {
    color: #94a3b8 !important;
    font-size: 16px !important;
    margin: 0 !important;
}

.auth-body {
    padding: 32px !important;
}

/* Form styles matching homepage */
.form-group {
    margin-bottom: 24px !important;
}

.form-label {
    display: block !important;
    font-weight: 500 !important;
    color: #cbd5e1 !important;
    margin-bottom: 8px !important;
    font-size: 14px !important;
}

.form-input {
    width: 100% !important;
    padding: 12px 16px !important;
    background: rgba(91, 46, 255, 0.05) !important;
    border: 1px solid rgba(91, 46, 255, 0.2) !important;
    border-radius: 8px !important;
    font-size: 15px !important;
    color: #F9F9FB !important;
    transition: all 0.2s !important;
    box-sizing: border-box !important;
}

.form-input::placeholder {
    color: #6b7280 !important;
}

.form-input:focus {
    outline: none !important;
    background: rgba(91, 46, 255, 0.08) !important;
    border-color: #EA7F3F !important;
    box-shadow: 0 0 0 3px rgba(234, 127, 63, 0.1) !important;
}

/* Checkbox group */
.form-checkbox-group {
    display: flex !important;
    align-items: center !important;
    gap: 12px !important;
    margin: 20px 0 !important;
    padding: 16px !important;
    background: rgba(91, 46, 255, 0.05) !important;
    border-radius: 8px !important;
    border: 1px solid rgba(91, 46, 255, 0.1) !important;
}

.form-checkbox {
    width: 18px !important;
    height: 18px !important;
    margin: 0 !important;
    accent-color: #EA7F3F !important;
    cursor: pointer !important;
}

.form-checkbox-label {
    color: #cbd5e1 !important;
    font-size: 14px !important;
    margin: 0 !important;
    cursor: pointer !important;
    user-select: none !important;
}

/* Buttons matching homepage style */
.auth-button {
    width: 100% !important;
    padding: 14px 24px !important;
    background: linear-gradient(135deg, #5B2EFF 0%, #EA7F3F 100%) !important;
    color: #ffffff !important;
    border: none !important;
    border-radius: 8px !important;
    font-size: 16px !important;
    font-weight: 600 !important;
    cursor: pointer !important;
    transition: all 0.3s !important;
    margin-top: 8px !important;
    text-decoration: none !important;
    display: block !important;
    text-align: center !important;
    box-sizing: border-box !important;
}

.auth-button:hover {
    transform: translateY(-2px) !important;
    box-shadow: 0 10px 25px rgba(234, 127, 63, 0.4) !important;
    background: linear-gradient(135deg, #6B3EFF 0%, #FA8F4F 100%) !important;
}

.auth-button:active {
    transform: translateY(0) !important;
}

/* Secondary button style */
.auth-link {
    display: block !important;
    text-align: center !important;
    color: #5B2EFF !important;
    text-decoration: none !important;
    font-weight: 500 !important;
    padding: 14px 24px !important;
    border: 1px solid rgba(91, 46, 255, 0.3) !important;
    border-radius: 8px !important;
    transition: all 0.2s !important;
    background: transparent !important;
    margin-top: 16px !important;
}

.auth-link:hover {
    background: rgba(91, 46, 255, 0.1) !important;
    border-color: #EA7F3F !important;
    color: #EA7F3F !important;
    transform: translateY(-1px) !important;
}

/* Message styles */
.error-message {
    background: rgba(239, 68, 68, 0.1) !important;
    border: 1px solid rgba(239, 68, 68, 0.3) !important;
    color: #fca5a5 !important;
    padding: 14px 16px !important;
    border-radius: 8px !important;
    margin-bottom: 24px !important;
    font-size: 14px !important;
    text-align: center !important;
}

.success-message {
    background: rgba(34, 197, 94, 0.1) !important;
    border: 1px solid rgba(34, 197, 94, 0.3) !important;
    color: #86efac !important;
    padding: 14px 16px !important;
    border-radius: 8px !important;
    margin-bottom: 24px !important;
    font-size: 14px !important;
    text-align: center !important;
}

.invite-info {
    background: rgba(91, 46, 255, 0.1) !important;
    border: 1px solid rgba(91, 46, 255, 0.2) !important;
    border-radius: 8px !important;
    padding: 16px !important;
    margin-bottom: 24px !important;
    text-align: center !important;
}

.invite-info h4 {
    margin: 0 0 8px 0 !important;
    color: #5B2EFF !important;
    font-size: 16px !important;
}

.invite-info p {
    margin: 0 !important;
    color: #94a3b8 !important;
    font-size: 14px !important;
}

/* Divider */
.auth-divider {
    margin: 28px 0 !important;
    text-align: center !important;
    color: #6b7280 !important;
    font-size: 14px !important;
    position: relative !important;
}

.auth-divider::before {
    content: '' !important;
    position: absolute !important;
    top: 50% !important;
    left: 0 !important;
    right: 0 !important;
    height: 1px !important;
    background: rgba(91, 46, 255, 0.2) !important;
}

.auth-divider span {
    background: rgba(34, 34, 59, 0.4) !important;
    padding: 0 16px !important;
    position: relative !important;
}

/* Form helper text */
.form-help {
    color: #6b7280 !important;
    font-size: 12px !important;
    margin-top: 4px !important;
    display: block !important;
}

/* Show our custom content */
.modern-auth-content {
    display: block !important;
}

/* Responsive design */
@media (max-width: 480px) {
    .auth-wrapper {
        padding: 16px !important;
    }
    
    .auth-header {
        padding: 24px !important;
    }
    
    .auth-body {
        padding: 24px !important;
    }
    
    .auth-title {
        font-size: 24px !important;
    }
}
</style>
'''
    
    # Insert modern styles before closing head tag
    html = html.replace('</head>', modern_dark_styles + '</head>')
    
    # Enhanced login page structure
    if server.path.startswith('/login'):
        html = add_modern_login_content(html, server)
    
    # Enhanced register page structure  
    elif server.path.startswith('/register'):
        html = add_modern_register_content(html, server)
    
    return html


def add_modern_login_content(html, server):
    """Add modern dark login content to the page"""
    
    # Extract any error message
    error_message = ''
    if 'wrong=' in server.path:
        error_message = '''
        <div class="error-message">
            Invalid username or password
        </div>
        '''
    
    # Extract redirect value if present
    redirect_field = ''
    if 'redirect=' in server.path:
        import urllib.parse
        parsed = urllib.parse.parse_qs(urllib.parse.urlparse(server.path).query)
        if 'redirect' in parsed:
            redirect_value = parsed['redirect'][0]
            redirect_field = f'<input type="hidden" name="redirect" value="{redirect_value}">'
    
    modern_login_content = f'''
    <div class="modern-auth-content">
        <div class="auth-wrapper">
            <div class="auth-container">
                <div class="auth-card">
                    <div class="auth-header">
                        <h1 class="auth-title">Welcome Back</h1>
                        <p class="auth-subtitle">Sign in to your account</p>
                    </div>
                    
                    <div class="auth-body">
                        {error_message}
                        
                        <form action="do_login" method="post">
                            <div class="form-group">
                                <label for="user_name" class="form-label">Username</label>
                                <input 
                                    type="text" 
                                    id="user_name" 
                                    name="user_name" 
                                    class="form-input"
                                    placeholder="Enter your username"
                                    pattern="[A-Za-z0-9\\.\\-\\_]*"
                                    maxlength="500"
                                    required
                                    autocomplete="username"
                                >
                            </div>
                            
                            <div class="form-group">
                                <label for="password" class="form-label">Password</label>
                                <input 
                                    type="password" 
                                    id="password" 
                                    name="password" 
                                    class="form-input"
                                    placeholder="Enter your password"
                                    maxlength="500"
                                    required
                                    autocomplete="current-password"
                                >
                            </div>
                            
                            <div class="form-checkbox-group">
                                <input type="checkbox" id="logout" name="logout" class="form-checkbox">
                                <label for="logout" class="form-checkbox-label">Log out other sessions</label>
                            </div>
                            
                            {redirect_field}
                            
                            <button type="submit" class="auth-button">
                                Sign In
                            </button>
                        </form>
                        
                        <div class="auth-divider">
                            <span>Don't have an account?</span>
                        </div>
                        
                        <a href="/register" class="auth-link">
                            Create Account
                        </a>
                    </div>
                </div>
            </div>
        </div>
    </div>
    '''
    
    # Insert before the closing body tag
    html = html.replace('</body>', modern_login_content + '</body>')
    
    return html


def add_modern_register_content(html, server):
    """Add modern dark register content to the page"""
    
    # Extract parameters
    error_message = ''
    code_field = ''
    invite_info = ''
    
    if 'userexists=' in server.path:
        error_message = '''
        <div class="error-message">
            Username is already taken
        </div>
        '''
    
    if 'wrongcode=' in server.path:
        error_message = '''
        <div class="error-message">
            Invalid invite code
        </div>
        '''
    
    # Check if we have a code parameter
    code_value = ''
    if 'code=' in server.path:
        import urllib.parse
        parsed = urllib.parse.parse_qs(urllib.parse.urlparse(server.path).query)
        if 'code' in parsed:
            code_value = parsed['code'][0]
            code_field = f'<input type="hidden" name="code" value="{code_value}">'
            invite_info = '''
            <div class="invite-info">
                <h4>Registration Invitation</h4>
                <p>You've been invited to join! Complete your registration below.</p>
            </div>
            '''
    
    # Determine form content based on whether we have a code
    if not code_value and 'code=' not in server.path:
        # Show invite code input
        form_content = '''
        <div class="form-group">
            <label for="code" class="form-label">Invite Code</label>
            <input 
                type="text" 
                id="code" 
                name="code" 
                class="form-input"
                placeholder="Enter your invite code"
                maxlength="500"
                required
                autocomplete="off"
            >
            <small class="form-help">
                Enter the invitation code provided to you
            </small>
        </div>
        
        <button type="submit" class="auth-button">
            Continue
        </button>
        '''
        subtitle = "Enter your invite code to continue"
    else:
        # Show full registration form
        form_content = f'''
        {code_field}
        
        <div class="form-group">
            <label for="user_name" class="form-label">Username</label>
            <input 
                type="text" 
                id="user_name" 
                name="user_name" 
                class="form-input"
                placeholder="Choose your username"
                pattern="[A-Za-z0-9\\.\\-\\_]*"
                maxlength="500"
                required
                autocomplete="username"
            >
            <small class="form-help">
                Letters, numbers, dots, hyphens, and underscores only
            </small>
        </div>
        
        <div class="form-group">
            <label for="password" class="form-label">Password</label>
            <input 
                type="password" 
                id="password" 
                name="password" 
                class="form-input"
                placeholder="Create a secure password"
                maxlength="500"
                required
                autocomplete="new-password"
            >
        </div>
        
        <button type="submit" class="auth-button">
            Create Account
        </button>
        '''
        subtitle = "Complete your registration"
    
    modern_register_content = f'''
    <div class="modern-auth-content">
        <div class="auth-wrapper">
            <div class="auth-container">
                <div class="auth-card">
                    <div class="auth-header">
                        <h1 class="auth-title">Join Us</h1>
                        <p class="auth-subtitle">{subtitle}</p>
                    </div>
                    
                    <div class="auth-body">
                        {error_message}
                        {invite_info}
                        
                        <form action="do_register" method="post">
                            {form_content}
                        </form>
                        
                        <div class="auth-divider">
                            <span>Already have an account?</span>
                        </div>
                        
                        <a href="/login" class="auth-link">
                            Sign In
                        </a>
                    </div>
                </div>
            </div>
        </div>
    </div>
    '''
    
    # Insert before the closing body tag
    html = html.replace('</body>', modern_register_content + '</body>')
    
    return html
